[![Test on master](https://img.shields.io/travis/pywbem/pywbem/master.svg?style=plastic&label=test%20on%20master)](https://travis-ci.org/pywbem/pywbem/branches)
[![PyPI version](https://img.shields.io/pypi/v/pywbem.svg?style=plastic&label=PyPI%20version)](https://pypi.python.org/pypi/pywbem)

PyWBEM Client
-------------

The PyWBEM Client project provides a WBEM client library and some related
utilities, written in pure Python.

A WBEM client allows issuing operations to a WBEM server, using the CIM
operations over HTTP (CIM-XML) protocol defined in the DMTF standards
DSP0200 and DSP0201. See http://www.dmtf.org/standards/wbem for information
about WBEM. This is used for all kinds of systems management tasks that are
supported by the system running the WBEM server.

Usage
-----

For information on how to use the PyWBEM Client for your own development
projects, or how to contribute to it, go to the
[PyWBEM Client page](http://pywbem.github.io/pywbem/)

License
-------

The PyWBEM Client is provided under the
[GNU Lesser General Public License (LGPL) version 2.1](src/pywbem/LICENSE.txt),
or (at your option) any later version.
